# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 0.x.x   | :white_check_mark: |


## Reporting a Vulnerability

Please use the security report in GitHub.
